package com.ruoyi.app.service;

import com.ruoyi.app.domain.AppPendingStorage;
import com.ruoyi.app.domain.DTO.OtherStockInRequest;

import java.util.List;


/**
 * 入库码盘Service接口
 * 
 * @author ruoyi
 * @date 2025-02-22
 */
public interface IAppPendingStorageService 
{
    /**
     * 查询入库码盘
     * 
     * @param recordId 入库码盘主键
     * @return 入库码盘
     */
    public AppPendingStorage selectAppPendingStorageByRecordId(String recordId);

    /**
     * 查询入库码盘列表
     * 
     * @param appPendingStorage 入库码盘
     * @return 入库码盘集合
     */
    public List<AppPendingStorage> selectAppPendingStorageList(AppPendingStorage appPendingStorage);

    /**
     * 新增入库码盘
     * 
     * @param appPendingStorage 入库码盘
     * @return 结果
     */
    public int insertAppPendingStorage(AppPendingStorage appPendingStorage);

    /**
     * 修改入库码盘
     * 
     * @param appPendingStorage 入库码盘
     * @return 结果
     */
    public int updateAppPendingStorage(AppPendingStorage appPendingStorage);

    /**
     * 批量删除入库码盘
     * 
     * @param recordIds 需要删除的入库码盘主键集合
     * @return 结果
     */
    public int deleteAppPendingStorageByRecordIds(String[] recordIds);

    /**
     * 删除入库码盘信息
     * 
     * @param recordId 入库码盘主键
     * @return 结果
     */
    public int deleteAppPendingStorageByRecordId(String recordId);

    /**
     * 添加空载具入库码盘信息
     *
     * @param vehicleNo 载具号
     * @return 结果
     */
    public int addAppEmptyPmsOrderIn(String vehicleNo);

    /** 添加物料列表入库
     *
     *  @param otherStockInRequest 数据
     *  @return 结果
     */
    public int addAppListPmsOrderIn(OtherStockInRequest otherStockInRequest);
}
